For class `Sparse', the inclusion probability is used to indicate the importance of predictors.
Here we use a binary indicator \(\phi\) to denote that the membership of the non-spike distribution.
Take the main effect of the \(j\)th genetic factor, \(X_{j}\), as an example.
Suppose we have collected H posterior samples from MCMC after burn-ins. The \(j\)th G factor is included
in the marginal G\(\times\)E model at the \(j\)th MCMC iteration if the corresponding indicator is 1, i.e., \(\phi_j^{(h)} = 1\).
Subsequently, the posterior probability of retaining the \(j\)th genetic main effect in the final marginal model is defined as the average of all the indicators for the \(j\)th G factor among the H posterior samples.
That is, \(p_j = \hat{\pi} (\phi_j = 1|y) = \frac{1}{H} \sum_{h=1}^{H} \phi_j^{(h)}, \; j = 1, \dots,p.\)
A larger posterior inclusion probability of \(j\)th indicates a stronger empirical evidence that the \(j\)th genetic main effect has a non-zero coefficient, i.e., a stronger association with the phenotypic trait.
Here, we use 0.5 as a cutting-off point. If \(p_j > 0.5\), then the \(j\)th genetic main effect is included in the final model. Otherwise, the \(j\)th genetic main effect is excluded in the final model.
For class `NonSparse', variable selection is based on 95% credible interval.
Please check the references for more details about the variable selection.